@@ -1,7 +1,7 @@
 
 /************************************************************************* 
- * Version 1.0  on  23-May-1997
- * (c) 1997 Pralay Dakua (pkanti@hotmail.com)
+ * Version 1.1  on  16-Dec-1998
+ * (c) 1998 Pralay Dakua (pkanti@hotmail.com)
  *     
  * This is a free software and permission to use, modify, distribute,
  * selling and using for commercial purpose is hereby granted provided
@@ -134,8 +134,8 @@ static XtResource resources[]={
 	XmRPixel,
 	sizeof(Pixel),
 	offset(toolbar.tip_foreground),
-	XmRCallProc,
-	(XtPointer)_XmForegroundColorDefault
+	XmRString,
+	"Black"
 	},
 	{
 	XmNtipBackground,
@@ -143,8 +143,8 @@ static XtResource resources[]={
 	XmRPixel,
 	sizeof(Pixel),
 	offset(toolbar.tip_background),
-	XmRCallProc,
-	(XtPointer)_XmBackgroundColorDefault
+	XmRString,
+	"White"
 	},
 	{
 	XmNtipBorderWidth,
